@@ -6,11 +6,13 @@
 
 #include "version.h"
 #include "sysfs.h"
+#include "jedec.h"
 #include "osutils.h"
 
+#include <stdlib.h>
 #include <regex.h>
 
-__ID("@(#) $Id: heuristics.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: heuristics.cc 2336 2010-10-05 09:34:27Z lyonel $");
 
 string guessBusInfo(const string & info)
 {
@@ -115,6 +117,9 @@ bool guessVendor(hwNode & device)
   int i = 0;
   bool result = false;
 
+
+  device.setVendor(jedec_resolve(device.getVendor()));
+
   if(device.getVendor() != "")
     return false;
 
@@ -133,3 +138,41 @@ bool guessVendor(hwNode & device)
   return result;
 }
 
+
+static string parsehex(const string & s)
+{
+  int i = 0;
+  string result = "";
+
+  if(matches(s,"^0x[[:xdigit:]][[:xdigit:]]+$"))
+  {
+    for(i=2; i<s.length(); i+=2)
+    {
+      string c = s.substr(i,2);
+      static char code[2];
+
+      code[0] = strtol(c.c_str(), NULL, 16);
+      code[1] = '\0';
+      
+      if(code[0] < ' ') return s;
+      result += string(code);
+    }
+   }
+   else
+     return s;
+
+  return result;
+}
+
+bool guessProduct(hwNode & device)
+{
+  string product = device.getProduct();
+
+  if(product == "")
+    return false;
+
+  device.setProduct(parsehex(product));
+
+  return true;
+}
+ 
