@@ -10,11 +10,12 @@
  */
 
 #include "version.h"
+#include "config.h"
 #include "lvm.h"
 #include "osutils.h"
 #include <string.h>
 
-__ID("@(#) $Id: lvm.cc 2069 2009-02-12 22:53:09Z lyonel $");
+__ID("@(#) $Id: lvm.cc 2336 2010-10-05 09:34:27Z lyonel $");
 
 #define LABEL_ID "LABELONE"
 #define LABEL_SIZE BLOCKSIZE                      /* Think very carefully before changing this */
@@ -86,7 +87,7 @@ uint32_t calc_crc(uint32_t initial, void *buf, uint32_t size)
 }
 
 
-static const char *id = "@(#) $Id: lvm.cc 2069 2009-02-12 22:53:09Z lyonel $";
+static const char *id = "@(#) $Id: lvm.cc 2336 2010-10-05 09:34:27Z lyonel $";
 
 static string uuid(void * s)
 {
@@ -128,7 +129,7 @@ bool scan_lvm(hwNode & n, source & s)
 
       memcpy(&pvh, sector+lh.offset_xl, sizeof(pvh));
       if(n.getDescription()=="")
-        n.setDescription("Linux LVM Physical Volume");
+        n.setDescription(_("Linux LVM Physical Volume"));
       n.addCapability("lvm2");
       n.setSerial(uuid(pvh.pv_uuid));
       if(n.getCapacity()==0)
