@@ -16,13 +16,14 @@
  */
 
 #include "version.h"
+#include "config.h"
 #include "mem.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
 
-__ID("@(#) $Id: mem.cc 2069 2009-02-12 22:53:09Z lyonel $");
+__ID("@(#) $Id: mem.cc 2336 2010-10-05 09:34:27Z lyonel $");
 
 static unsigned long long get_kcore_size()
 {
@@ -121,7 +122,7 @@ bool scan_memory(hwNode & n)
     memory->addHint("icon", string("memory"));
 
     if (memory->getDescription() == "")
-      memory->setDescription("System memory");
+      memory->setDescription(_("System memory"));
 
     if (memory->getSize() > logicalmem)           // we already have a value
       return true;
