@@ -14,9 +14,11 @@
 #include <string>
 #include <map>
 
+#include <stdlib.h>
+
 using namespace std;
 
-__ID("@(#) $Id: options.cc 2069 2009-02-12 22:53:09Z lyonel $");
+__ID("@(#) $Id: options.cc 2336 2010-10-05 09:34:27Z lyonel $");
 
 static set < string > disabled_tests;
 static set < string > visible_classes;
@@ -76,10 +78,24 @@ char *argv[])
 
       remove_option_argument(i, argc, argv);
     }
+#ifdef SQLITE
+    else if (option == "-dump")
+    {
+      if (i + 1 >= argc)
+        return false;                             // -dump requires an argument
+
+      setenv("OUTFILE", argv[i + 1], 1);
+      enable("output:db");
+
+      remove_option_argument(i, argc, argv);
+    }
+#endif
     else if ( (option == "-class") || (option == "-C") || (option == "-c"))
     {
       vector < string > classes;
 
+      enable("output:list");
+
       if (i + 1 >= argc)
         return false;                             // -class requires an argument
 
