@@ -15,11 +15,12 @@
 #include <stdio.h>
 #include <errno.h>
 #include <wchar.h>
+#include <sys/utsname.h>
 #ifndef MINOR
 #include <linux/kdev_t.h>
 #endif
 
-__ID("@(#) $Id: osutils.cc 2069 2009-02-12 22:53:09Z lyonel $");
+__ID("@(#) $Id: osutils.cc 2336 2010-10-05 09:34:27Z lyonel $");
 
 using namespace std;
 
@@ -425,20 +426,53 @@ string escape(const string & s)
 {
   string result = "";
 
+  for (unsigned int i = 0; i < s.length(); i++)
+    // #x9 | #xA | #xD | [#x20-#xD7FF] | [#xE000-#xFFFD] | [#x10000-#x10FFFF]
+    if (s[i] == 0x9
+        || s[i] == 0xA
+        || s[i] == 0xD
+        || (s[i] >= 0x20 && s[i] <= 0xD7FF)
+        || (s[i] >= 0xE000 && s[i] <= 0xFFFD)
+        || (s[i] >= 0x10000 && s[i] <= 0x10FFFF))
+      switch (s[i])
+      {
+        case '<':
+          result += "&lt;";
+          break;
+        case '>':
+          result += "&gt;";
+          break;
+        case '&':
+          result += "&amp;";
+          break;
+        case '"':
+          result += "&quot;";
+          break;
+      default:
+        result += s[i];
+    }
+
+  return result;
+}
+
+string escapeJSON(const string & s)
+{
+  string result = "";
+
   for (unsigned int i = 0; i < s.length(); i++)
     switch (s[i])
     {
-      case '<':
-        result += "&lt;";
+      case '\r':
+        result += "\\r";
         break;
-      case '>':
-        result += "&gt;";
+      case '\n':
+        result += "\\n";
         break;
-      case '&':
-        result += "&amp;";
+      case '\t':
+        result += "\\t";
         break;
       case '"':
-        result += "&quot;";
+        result += "\\\"";
         break;
     default:
       result += s[i];
@@ -716,3 +750,81 @@ string kilobytes(unsigned long long value)
 
   return out.str();
 }
+
+string operating_system()
+{
+  vector<string> osinfo;
+  struct utsname u;
+  string os = "";
+
+  if(loadfile("/etc/lsb-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/lsb_release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/system-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/arch-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/arklinux-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/aurox-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/conectiva-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/debian_version", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/fedora-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/gentoo-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/linuxppc-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/mandrake-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/mandriva-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/novell-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/pld-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/redhat-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/slackware-version", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/sun-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/SuSE-release", osinfo))
+    os = osinfo[0];
+  else if(loadfile("/etc/yellowdog-release", osinfo))
+    os = osinfo[0];
+
+  if(uname(&u) != 0) return "";
+
+  os += (os == ""?"":" ; ") + string(u.sysname)+" "+string(u.release);
+
+#if defined(__GLIBC__) && defined(_CS_GNU_LIBC_VERSION)
+  char version[PATH_MAX];
+
+      if(confstr(_CS_GNU_LIBC_VERSION, version, sizeof(version))>0)
+        os += " ; "+string(version);
+#endif
+
+  return os;
+}
+
+string platform()
+{
+  string p = "";
+  struct utsname u;
+
+#ifdef __i386__
+  p = "i386";
+#endif
+
+  if(uname(&u) != 0)
+    return p;
+  else
+    return p + (p!=""?"/":"") + string(u.machine);
+}
