@@ -29,7 +29,7 @@
 #include <unistd.h>
 #include <stdint.h>
 
-__ID("@(#) $Id: partitions.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: partitions.cc 2336 2010-10-05 09:34:27Z lyonel $");
 
 #define LIFBLOCKSIZE 256
 
@@ -57,7 +57,7 @@ static struct maptypes map_types[] =
   {"solaris-x86", "Solaris disklabel", NULL},
   {"solaris-sparc", "Solaris disklabel", NULL},
   {"raid", "Linux RAID", NULL},
-  {"lvm", "Linux LVM", NULL},
+  {"lvm", "Linux LVM Physical Volume", NULL},
   {"atari", "Atari ST", NULL},
   {"amiga", "Amiga", NULL},
   { NULL, NULL, NULL }
@@ -225,9 +225,11 @@ static struct systypes dos_sys_types[] =
   },
   {0xa6, "OpenBSD", "openbsd", "", ""},
   {0xa7, "NeXTSTEP", "nextstep", "", ""},
-  {0xa8, "Darwin UFS", "darwin", "", ""},
+  {0xa8, "Darwin/OS X UFS", "darwin", "", ""},
   {0xa9, "NetBSD", "netbsd", "", ""},
-  {0xab, "Darwin boot", "", "boot,nofs", ""},
+  {0xab, "Darwin/OS X boot", "", "boot,nofs", ""},
+  {0xac, "Darwin/OS X RAID", "", "multi", "md"},
+  {0xaf, "Darwin/OS X HFS+", "hfs", "", ""},
   {0xb7, "BSDI fs", "", "", ""},
   {0xb8, "BSDI swap", "", "nofs", ""},
   {0xbb, "Boot Wizard hidden", "", "boot,nofs", ""},
@@ -890,7 +892,7 @@ static bool detect_gpt(source & s, hwNode & n)
       else
       if(p.PartitionTypeGUID == PARTITION_LVM_GUID)
       {
-        partition.setDescription("Linux LVM physical volume");
+        partition.setDescription("Linux LVM Physical Volume");
         partition.addCapability("multi");
       }
       else
@@ -1155,6 +1157,7 @@ static bool detect_lif(source & s, hwNode & n)
   ipl_length = be_long(buffer+244);               // size of boot code
   ipl_entry = be_long(buffer+248);                // boot code entry point
 
+#if 0
   fprintf(stderr, "system: %x\n", be_short(buffer+12));
   fprintf(stderr, "start of directory: %ld\n", dir_start);
   fprintf(stderr, "length of directory: %ld\n", dir_length);
@@ -1165,6 +1168,7 @@ static bool detect_lif(source & s, hwNode & n)
   fprintf(stderr, "ipl addr: %ld\n", ipl_addr);
   fprintf(stderr, "ipl length: %ld\n", ipl_length);
   fprintf(stderr, "ipl entry point: %lx\n", ipl_entry);
+#endif
 
   if((ipl_addr!=0) && (ipl_length>0)) n.addCapability("bootable", "Bootable disk");
 
