@@ -1,4 +1,5 @@
 #include "version.h"
+#include "config.h"
 #include "pci.h"
 #include "osutils.h"
 #include "options.h"
@@ -12,7 +13,7 @@
 #include <stdlib.h>
 #include <dirent.h>
 
-__ID("@(#) $Id: pci.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: pci.cc 2336 2010-10-05 09:34:27Z lyonel $");
 
 #define PROC_BUS_PCI "/proc/bus/pci"
 #define SYS_BUS_PCI "/sys/bus/pci"
@@ -369,7 +370,7 @@ static const char *get_class_name(unsigned int c)
     case PCI_BASE_CLASS_COMMUNICATION:
       return "communication";
     case PCI_BASE_CLASS_SYSTEM:
-      return "system";
+      return "generic";
     case PCI_BASE_CLASS_INPUT:
       return "input";
     case PCI_BASE_CLASS_DOCKING:
@@ -721,7 +722,7 @@ static bool scan_capabilities(hwNode & n, struct pci_dev &d)
         n.addCapability("agp8x", "AGP 8x");
         break;
       case PCI_CAP_ID_EXP:
-        n.addCapability("pciexpress", "PCI Express");
+        n.addCapability("pciexpress", _("PCI Express"));
         break;
       case PCI_CAP_ID_MSIX:
         n.addCapability("msix", "MSI-X");
@@ -881,7 +882,7 @@ static hwNode *scan_pci_dev(struct pci_dev &d, hwNode & n)
               deviceicon = "modem";
             break;
           case PCI_BASE_CLASS_SYSTEM:
-            deviceclass = hw::system;
+            deviceclass = hw::generic;
             break;
           case PCI_BASE_CLASS_INPUT:
             deviceclass = hw::input;
@@ -1122,18 +1123,60 @@ bool scan_pci(hwNode & n)
 
       if(device)
       {
+        string resourcename = string(devices[i]->d_name)+"/resource";
+
         device->setBusInfo(devices[i]->d_name);
         if(exists(string(devices[i]->d_name)+"/driver"))
         {
-          char *drivername = strdup(readlink(string(devices[i]->d_name)+"/driver").c_str());
-          char *modulename = strdup(readlink(string(devices[i]->d_name)+"/driver/module").c_str());
-          device->setConfig("driver", basename(drivername));
-          if(exists(string(devices[i]->d_name)+"/driver/module"))
-            device->setConfig("module", basename(modulename));
-          if(drivername)
-            free(drivername);
+          string drivername = readlink(string(devices[i]->d_name)+"/driver");
+          string modulename = readlink(string(devices[i]->d_name)+"/driver/module");
+
+          device->setConfig("driver", basename(drivername.c_str()));
+          if(exists(modulename))
+            device->setConfig("module", basename(modulename.c_str()));
+
+          if(exists(string(devices[i]->d_name)+"/rom"))
+          {
+            device->addCapability("rom", "extension ROM");
+          }
+
+          if(exists(string(devices[i]->d_name)+"/irq"))
+          {
+            long irq = get_number(string(devices[i]->d_name)+"/irq", -1);
+            if(irq>=0)
+              device->addResource(hw::resource::irq(irq));
+          }
           device->claim();
         }
+
+        if(exists(resourcename))
+        {
+            FILE*resource = fopen(resourcename.c_str(), "r");
+
+            if(resource)
+            {
+              while(!feof(resource))
+              {
+                uint64_t start, end, flags;
+
+                start = end = flags = 0;
+
+                if(fscanf(resource, "%llx %llx %llx", &start, &end, &flags) != 3)
+                  break;
+
+                if(flags & 0x101)
+                  device->addResource(hw::resource::ioport(start, end));
+                else
+                if(flags & 0x100)
+                  device->addResource(hw::resource::iomem(start, end));
+                else
+                if(flags & 0x200)
+                  device->addResource(hw::resource::mem(start, end, flags & 0x1000));
+              }
+              fclose(resource);
+            }
+        }
+
         result = true;
       }
 
