@@ -27,7 +27,7 @@
 #include <string>
 #include <map>
 
-__ID("@(#) $Id: scsi.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: scsi.cc 2336 2010-10-05 09:34:27Z lyonel $");
 
 #define SG_X "/dev/sg%d"
 #define SG_MAJOR 21
@@ -842,7 +842,7 @@ static bool scan_hosts(hwNode & node)
 
           if (!controller)
           {
-            controller = node.addChild(hwNode::hwNode("scsi", hw::storage));
+            controller = node.addChild(hwNode("scsi", hw::storage));
             if (controller)
             {
               controller->setLogicalName(host_logicalname(number));
