@@ -1,17 +1,14 @@
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
 #include <stdbool.h>
 #include <unistd.h>
 #include <gtk/gtk.h>
 
 #include "interface.h"
 #include "support.h"
+#include "config.h"
 #include "stock.h"
 #include "engine.h"
 
-static char *id = "@(#) $Id: gtk-lshw.c 2069 2009-02-12 22:53:09Z lyonel $";
+static char *id = "@(#) $Id: gtk-lshw.c 2336 2010-10-05 09:34:27Z lyonel $";
 
 GtkWidget *mainwindow;
 
@@ -19,10 +16,10 @@ int
 main (int argc, char *argv[])
 {
   GdkPixbuf *icon;
-#ifdef ENABLE_NLS
-  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
+#ifndef NONLS
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset (PACKAGE, "UTF-8");
+  textdomain (PACKAGE);
 #endif
 
   gtk_set_locale ();
