@@ -12,34 +12,40 @@
 #include <stdlib.h>
 #include <iostream>
 
-__ID("@(#) $Id: lshw.cc 1959 2008-05-09 20:32:50Z lyonel $");
+#ifndef NONLS
+#include <locale.h>
+#endif
+
+__ID("@(#) $Id: lshw.cc 2336 2010-10-05 09:34:27Z lyonel $");
 
 void usage(const char *progname)
 {
   fprintf(stderr, "Hardware Lister (lshw) - %s\n", getpackageversion());
-  fprintf(stderr, "usage: %s [-format] [-options ...]\n", progname);
-  fprintf(stderr, "       %s -version\n", progname);
+  fprintf(stderr, _("usage: %s [-format] [-options ...]\n"), progname);
+  fprintf(stderr, _("       %s -version\n"), progname);
   fprintf(stderr, "\n");
-  fprintf(stderr, "\t-version        print program version (%s)\n", getpackageversion());
-  fprintf(stderr, "\nformat can be\n");
-  fprintf(stderr, "\t-html           output hardware tree as HTML\n");
-  fprintf(stderr, "\t-xml            output hardware tree as XML\n");
-  fprintf(stderr, "\t-short          output hardware paths\n");
-  fprintf(stderr, "\t-businfo        output bus information\n");
+  fprintf(stderr, _("\t-version        print program version (%s)\n"), getpackageversion());
+  fprintf(stderr, _("\nformat can be\n"));
+  fprintf(stderr, _("\t-html           output hardware tree as HTML\n"));
+  fprintf(stderr, _("\t-xml            output hardware tree as XML\n"));
+  fprintf(stderr, _("\t-short          output hardware paths\n"));
+  fprintf(stderr, _("\t-businfo        output bus information\n"));
   if(getenv("DISPLAY") && exists(SBINDIR"/gtk-lshw"))
-    fprintf(stderr, "\t-X              use graphical interface\n");
-  fprintf(stderr, "\noptions can be\n");
+    fprintf(stderr, _("\t-X              use graphical interface\n"));
+  fprintf(stderr, _("\noptions can be\n"));
+#ifdef SQLITE
+  fprintf(stderr, _("\t-dump OUTFILE   save hardware tree to a file\n"));
+#endif
+  fprintf(stderr, _("\t-class CLASS    only show a certain class of hardware\n"));
+  fprintf(stderr, _("\t-C CLASS        same as '-class CLASS'\n"));
+  fprintf(stderr, _("\t-c CLASS        same as '-class CLASS'\n"));
   fprintf(stderr,
-    "\t-class CLASS    only show a certain class of hardware\n");
-  fprintf(stderr, "\t-C CLASS        same as '-class CLASS'\n");
-  fprintf(stderr, "\t-c CLASS        same as '-class CLASS'\n");
+    _("\t-disable TEST   disable a test (like pci, isapnp, cpuid, etc. )\n"));
   fprintf(stderr,
-    "\t-disable TEST   disable a test (like pci, isapnp, cpuid, etc. )\n");
-  fprintf(stderr,
-    "\t-enable TEST    enable a test (like pci, isapnp, cpuid, etc. )\n");
-  fprintf(stderr, "\t-quiet          don't display status\n");
-  fprintf(stderr, "\t-sanitize       sanitize output (remove sensitive information like serial numbers, etc.)\n");
-  fprintf(stderr, "\t-numeric        output numeric IDs (for PCI, USB, etc.)\n");
+    _("\t-enable TEST    enable a test (like pci, isapnp, cpuid, etc. )\n"));
+  fprintf(stderr, _("\t-quiet          don't display status\n"));
+  fprintf(stderr, _("\t-sanitize       sanitize output (remove sensitive information like serial numbers, etc.)\n"));
+  fprintf(stderr, _("\t-numeric        output numeric IDs (for PCI, USB, etc.)\n"));
   fprintf(stderr, "\n");
 }
 
@@ -66,8 +72,18 @@ void status(const char *message)
 int main(int argc,
 char **argv)
 {
+
+#ifndef NONLS
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset (PACKAGE, "UTF-8");
+  textdomain (PACKAGE);
+#endif
+
   disable("isapnp");
 
+  disable("output:json");
+  disable("output:db");
   disable("output:xml");
   disable("output:html");
   disable("output:hwpath");
@@ -103,7 +119,7 @@ char **argv)
       if(latest)
       {
         if(strcmp(latest, getpackageversion()) != 0)
-          fprintf(stderr, "the latest version is %s\n", latest);
+          fprintf(stderr, _("the latest version is %s\n"), latest);
       }
       exit(0);
     }
@@ -128,6 +144,12 @@ char **argv)
       validoption = true;
     }
 
+    if (strcmp(argv[1], "-json") == 0)
+    {
+      enable("output:json");
+      validoption = true;
+    }
+
     if (strcmp(argv[1], "-xml") == 0)
     {
       enable("output:xml");
@@ -193,7 +215,7 @@ char **argv)
 
   if (geteuid() != 0)
   {
-    fprintf(stderr, "WARNING: you should run this program as super-user.\n");
+    fprintf(stderr, _("WARNING: you should run this program as super-user.\n"));
   }
 
   {
@@ -209,12 +231,24 @@ char **argv)
       printbusinfo(computer);
     else
     {
+      if (enabled("output:json"))
+        cout << computer.asJSON() << endl;
+      else
       if (enabled("output:xml"))
         cout << computer.asXML();
       else
         print(computer, enabled("output:html"));
     }
+
+    if(enabled("output:db"))
+      computer.dump(getenv("OUTFILE"));
   }
 
+  if (geteuid() != 0)
+  {
+    fprintf(stderr, _("WARNING: output may be incomplete or inaccurate, you should run this program as super-user.\n"));
+  }
+
+
   return 0;
 }
